autowisp.fit_expression.FitTermsParserVisitor module — AutoWISP documentation

# autowisp.fit_expression.FitTermsParserVisitor module

## Class Inheritance Diagram

class autowisp.fit_expression.FitTermsParserVisitor.FitTermsParserVisitor

  Bases: `ParseTreeVisitor`

  visitFit_polynomial(ctx: Fit_polynomialContext)
  visitFit_term(ctx: Fit_termContext)
  visitFit_terms_expression(ctx: Fit_terms_expressionContext)
  visitFit_terms_list(ctx: Fit_terms_listContext)
  visitFit_terms_set(ctx: Fit_terms_setContext)
  visitFit_terms_set_cross_product(ctx: Fit_terms_set_cross_productContext)